Front Matter — SQLSoup 0.9.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- SQLSoup 0.9.0 documentation »

# Front Matter

Information about the SQLSoup project.

## Project Homepage

SQLSoup is hosted on Bitbucket - the lead project page is at https://bitbucket.org/zzzeek/sqlsoup. Source code is tracked here using Mercurial.

Releases and project status are available on Pypi at http://pypi.python.org/pypi/sqlsoup.

The most recent published version of this documentation should be at http://readthedocs.org/docs/sqlsoup/.

## Project Status

SQLSoup has been included with the SQLAlchemy distribution for many years. As of 2012 it has been broken out into it’s own project, where it can be tracked and released separately. The community is also invited to collaborate on Bitbucket, create forks, and improve the product.

## Installation

Install released versions of SQLSoup from the Python package index with pip or a similar tool:

    pip install sqlsoup

Installation via source distribution is via the `setup.py` script:

    python setup.py install

### Dependencies

SQLSoup’s install process will ensure that SQLAlchemy is installed, in addition to other dependencies. The 0.7 series of SQLAlchemy or greater is recommended.

## Community

SQLSoup was originally written by Jonathan Ellis. It is under maintenance by Mike Bayer, and is loosely associated with the SQLAlchemy project.

## Bugs

Bugs and feature enhancements to SQLSoup should be reported on the Bitbucket issue tracker.

### Navigation

- index
- modules |
- next |
- previous |
- SQLSoup 0.9.0 documentation »